=== modified file 'bzrlib/mail_client.py'
--- bzrlib/mail_client.py	2007-08-10 00:03:44 +0000
+++ bzrlib/mail_client.py	2007-08-10 13:11:49 +0000
@@ -38,18 +38,25 @@
         raise NotImplementedError
 
     def compose_merge_request(self, to, subject, directive):
-        self.compose("Please describe these changes:", to, subject, directive,
+        prompt = self._get_merge_prompt("Please describe these changes:", to,
+                                        subject, directive)
+        self.compose(prompt, to, subject, directive,
             'x-patch', '.patch')
 
+    def _get_merge_prompt(self, prompt, to, subject, attachment):
+        return ''
+
 
 class Editor(MailClient):
     """DIY mail client that uses commit message editor"""
 
+    def _get_merge_prompt(self, prompt, to, subject, attachment):
+        return "%s\n\nTo: %s\nSubject: %s\n\n%s" % (prompt, to, subject,
+                attachment.decode('utf-8', 'replace'))
+
     def compose(self, prompt, to, subject, attachment, mime_subtype,
                 extension):
-        info = ("%s\n\nTo: %s\nSubject: %s\n\n%s" % (prompt, to, subject,
-                attachment))
-        body = msgeditor.edit_commit_message(info)
+        body = msgeditor.edit_commit_message(prompt)
         if body == '':
             raise errors.NoMessageSupplied()
         email_message.EmailMessage.send(self.config,

=== modified file 'bzrlib/tests/test_config.py'
--- bzrlib/tests/test_config.py	2007-08-09 20:43:00 +0000
+++ bzrlib/tests/test_config.py	2007-08-10 13:11:49 +0000
@@ -1019,6 +1019,10 @@
         client = config.get_mail_client()
         self.assertIsInstance(client, mail_client.Thunderbird)
 
+        config.set_user_option('mail_client', 'evolution')
+        client = config.get_mail_client()
+        self.assertIsInstance(client, mail_client.Evolution)
+
         config.set_user_option('mail_client', 'firebird')
         self.assertRaises(errors.UnknownMailClient, config.get_mail_client)
 

=== modified file 'bzrlib/tests/test_mail_client.py'
--- bzrlib/tests/test_mail_client.py	2007-08-10 00:03:44 +0000
+++ bzrlib/tests/test_mail_client.py	2007-08-10 13:11:49 +0000
@@ -45,3 +45,17 @@
                                                    'Hi there!', None)
         self.assertEqual(['mailto:jrandom@example.org?subject=Hi%20there%21'],
                          commandline)
+
+
+class TestEditor(tests.TestCase):
+
+    def test_get_merge_prompt_unicode(self):
+        """Prompt, to and subject are unicode, the attachement is binary"""
+        editor = mail_client.Editor(None)
+        prompt = editor._get_merge_prompt(u'foo\u1234',
+                                        u'bar\u1234',
+                                        u'baz\u1234',
+                                        u'qux\u1234'.encode('utf-8'))
+        self.assertContainsRe(prompt, u'foo\u1234(.|\n)*bar\u1234'
+                              u'(.|\n)*baz\u1234(.|\n)*qux\u1234')
+        editor._get_merge_prompt(u'foo', u'bar', u'baz', 'qux\xff')

